/**
 * @description  单页管理接口
 * @license Apache License Version 2.0
 * @Copyright (c) 2022-Now 少林寺驻北固山办事处大神父王喇嘛
 * @remarks
 * SimpleAdmin 基于 Apache License Version 2.0 协议发布，可用于商业项目，但必须遵守以下补充条款:
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改SimpleAdmin源码头部的版权声明。
 * 3.分发源码时候，请注明软件出处 https://gitee.com/dotnetmoyu/SimpleAdmin
 * 4.基于本软件的作品，只能使用 SimpleAdmin 作为后台服务，除外情况不可商用且不允许二次分发或开源。
 * 5.请不得将本软件应用于危害国家安全、荣誉和利益的行为，不能以任何形式用于非法为目的的行为不要删除和修改作者声明。
 * 6.任何基于本软件而产生的一切法律纠纷和责任，均于我司无关
 * @see https://gitee.com/dotnetmoyu/SimpleAdmin
 */
import { moduleRequest } from "@/api/request";
import { ReqId, ResPage, ReqPersonId, SysDormitory } from "@/api/interface";
const http = moduleRequest("/business/building/");
const httpChamber = moduleRequest("/business/dormitory/");

/**
 * @Description: 单页管理
 * @Author: wwp
 * @Date: 2023-12-15 15:34:54
 */
const userManageDormitoryApi = {
  // 获取宿舍楼树
  list(params: any) {
    return http.get("getNoPageList", params);
  },
  // 新增宿舍楼
  addDormitory(params: any) {
    return http.post("add", params);
  },
  // 修改宿舍楼
  updateDormitory(params: any) {
    return http.put("update", params);
  },
  // 删除宿舍楼
  deleteDormitory(params: ReqId) {
    return http.delete("delete", params);
  },
  // 获取寝室列表
  page(params: SysDormitory.Page) {
    return httpChamber.get("getPageList", params);
  },
  /** 新增寝室 */
  add(params: SysDormitory.ChamberInfo) {
    return httpChamber.post("add", params);
  },
  /** 修改寝室 */
  update(params: SysDormitory.ChamberInfo) {
    return httpChamber.put("update", params);
  },
  // 获取寝室列表
  info(params: SysDormitory.Page) {
    return httpChamber.get("getInfo", params);
  },
  /** 删除寝室 */
  delete(params: ReqId) {
    return httpChamber.delete("delete", params);
  },
  /**寝室分配人员*/
  assignPersonnel(params: SysDormitory.ChamberPersonnel) {
    return httpChamber.post("assignPersonnel", params);
  },
  /**归寝寝室列表*/
  returnList(params: any) {
    return httpChamber.get("getReturnPageList", params);
  },
  /**归寝寝室列表*/
  returnDetail(params: any) {
    return httpChamber.get("getReturnInfo", params);
  },
  /** 获取详情(带寝室人员) */
  detail(params: ReqId) {
    return httpChamber.get("getInfo", params);
  },
  /** 设置归寝时间 */
  setReturnTime(params: ReqId) {
    return httpChamber.post("setReturnTime", params);
  },
  /** 获取归寝时间 */
  getReturnTime(params: ReqId) {
    return httpChamber.get("getReturnTime", params);
  },
};

const dormitoryButtonCode = {
  /** 新增人员 */
  add: "userManageDormitoryAdd",
  /** 删除人员 */
  edit: "userManageDormitoryEdit",
  /** 删除人员 */
  delete: "userManageDormitoryDelete"
};

export { userManageDormitoryApi, dormitoryButtonCode };
